import { isDef } from '../utils/commonUtil';
import { PopupMixin } from '../mixins/popup';
import Icon from '../icon';
import Loading from '../loading';
import './index.less';

var Index = {
    mixins: [PopupMixin],

    props: {
        icon: String,
        className: null,
        loadingType: String,
        forbidClick: Boolean,
        closeOnClick: Boolean,
        message: [Number, String],
        type: {
            type: String,
            'default': 'text'
        },
        position: {
            type: String,
            'default': 'middle'
        },
        transition: {
            type: String,
            'default': 'sn-fade'
        },
        lockScroll: {
            type: Boolean,
            'default': false
        }
    },

    data: function data() {
        return {
            clickable: false,
            multiLine: false
        };
    },
    mounted: function mounted() {
        this.toggleClickable();
    },
    destroyed: function destroyed() {
        this.toggleClickable();
    },


    watch: {
        value: 'toggleClickable',
        forbidClick: 'toggleClickable',
        message: function message() {
            var _this = this;

            this.$nextTick(function () {
                var $toast = _this.$refs.toast;
                if ($toast && $toast instanceof HTMLElement) {
                    var height = $toast.getBoundingClientRect().height;
                    _this.multiLine = height > 40;
                }
            });
        }
    },

    methods: {
        onClick: function onClick() {
            if (this.closeOnClick) {
                this.close();
            }
        },
        toggleClickable: function toggleClickable() {
            var clickable = this.value && this.forbidClick;

            if (this.clickable !== clickable) {
                this.clickable = clickable;
                var action = clickable ? 'add' : 'remove';
                document.body.classList[action]('sn-toast-unclickable');
            }
        },


        /* istanbul ignore next */
        onAfterEnter: function onAfterEnter() {
            this.$emit('opened');

            if (this.onOpened) {
                this.onOpened();
            }
        },
        onAfterLeave: function onAfterLeave() {
            this.$emit('closed');
        },
        genIcon: function genIcon() {
            var h = this.$createElement;
            var icon = this.icon,
                type = this.type,
                loadingType = this.loadingType;

            var hasIcon = icon || type === 'success' || type === 'fail';

            if (hasIcon) {
                return h(Icon, { 'class': 'sn-toast-inner-icon', attrs: { type: icon || type }
                });
            }

            // if (type === 'loading') {
            //     return <Loading class='loading' type={loadingType} />;
            // }
        },
        genMessage: function genMessage() {
            var h = this.$createElement;
            var type = this.type,
                message = this.message;


            if (!isDef(message) || message === '') {
                return;
            }

            if (type === 'html') {
                return h('div', { 'class': 'sn-toast-inner-text', domProps: {
                        'innerHTML': message
                    }
                });
            }

            return h(
                'div',
                { 'class': 'sn-toast-inner-text' },
                [message]
            );
        }
    },

    render: function render() {
        var h = arguments[0];
        var position = this.position,
            icon = this.icon,
            type = this.type,
            className = this.className,
            multiLine = this.multiLine;

        var classNames = {
            'sn-toast': true,
            'sn-toast-icon': icon !== ''
        };
        classNames['sn-toast-' + position] = true;
        classNames['sn-toast-' + type] = true;
        classNames['sn-toast-multiline'] = multiLine;
        className && (classNames[className] = true);

        return h(
            'transition',
            {
                attrs: {
                    name: this.transition
                },
                on: {
                    'afterEnter': this.onAfterEnter,
                    'afterLeave': this.onAfterLeave
                }
            },
            [h(
                'div',
                {
                    ref: 'toast',
                    directives: [{
                        name: 'show',
                        value: this.value
                    }],

                    'class': classNames,
                    on: {
                        'click': this.onClick
                    }
                },
                [this.genIcon(), this.genMessage()]
            )]
        );
    }
};

export default Index;