import _extends from "babel-runtime/helpers/extends";
import defaultRequest from "./request";

function fileToObject(file) {
    return _extends({}, file, {
        lastModified: file.lastModified,
        lastModifiedDate: file.lastModifiedDate,
        name: file.name,
        size: file.size,
        type: file.type,
        uid: file.uid,
        percent: 0,
        originFileObj: file
    });
}

export default {
    name: "AjaxUploader",
    props: {
        multiple: {
            type: Boolean,
            "default": function _default() {
                return true;
            } // or false
        },
        disabled: {
            type: Boolean,
            "default": function _default() {
                return false;
            }
        },
        action: {
            type: String,
            "default": function _default() {
                return "";
            }
        },
        method: {
            type: String,
            "default": "POST"
        },
        headers: {
            "Content-Type": "multipart/form-data"
        },
        beforeUpload: Function,
        customRequest: Function
    },
    data: function data() {
        return {
            index: 0,
            now: +new Date(),
            uid: this.getUid(),
            reqs: function reqs() {
                return [];
            }
        };
    },
    beforeDestroy: function beforeDestroy() {
        this.abort();
    },

    methods: {
        getUid: function getUid() {
            return "vc-upload-" + this.now + "-" + ++this.index;
        },
        onClick: function onClick() {
            var el = this.$refs.fileInputRef;
            if (!el) {
                return;
            }
            el.click();
        },
        onChange: function onChange(e) {
            var files = e.target.files;
            if (files) {
                this.uploadfiles(files);
                this.$refs.fileInputRef.value = null;
            }
        },
        uploadfiles: function uploadfiles(files) {
            var _this = this;

            var fileList = Array.prototype.slice.call(files);
            if (!this.beforeUpload) {
                fileList.forEach(function (file) {
                    _this.post(file);
                });
            }
            var before = this.beforeUpload(fileList);
            if (before && before.then) {
                before.then(function (processFile) {
                    processFile.forEach(function (file) {
                        _this.post(file);
                    });
                })["catch"](function (e) {
                    console && console.log(e); // eslint-disable-line
                });
            } else if (before !== false) {
                fileList.forEach(function (file) {
                    _this.post(file);
                });
            }
        },
        post: function post(file) {
            var _this2 = this;

            var _getUid = this.getUid(),
                uid = _getUid.uid;

            file.uid = uid;
            var fileObj = void 0;
            if (typeof file === "object" && file.status === "upload-error") {
                fileObj = _extends({}, file);
                file = file.originFileObj;
            } else {
                fileObj = fileToObject(file);
            }
            var action = file.uploadUrl || this.$props["action"];
            var request = this.customRequest || defaultRequest;
            var options = {
                action: action,
                data: file,
                headers: this.headers,
                method: this.method,
                onProgress: function onProgress(e) {
                    _this2.$emit("progress", e, fileObj);
                },
                onSuccess: function onSuccess(ret, xhr) {
                    if (file.currentChunk >= file.chunks) {
                        delete _this2.reqs[uid];
                    }
                    fileObj.options = options;
                    _this2.$emit("success", fileObj, ret, xhr);
                },
                onError: function onError(err, ret) {
                    console.log("directUpload failed. fileName: ");
                    delete _this2.reqs[uid];
                    _this2.$emit("error", err, ret, fileObj);
                }
            };
            this.$emit("start", fileObj);
            this.reqs[uid] = request(options);
        },
        abort: function abort(file) {
            var reqs = this.reqs;

            Object.keys(reqs).forEach(function (uid) {
                if (reqs[uid]) {
                    reqs[uid].abort();
                }
                delete reqs[uid];
            });
        }
    },
    render: function render() {
        var h = arguments[0];
        var _$props = this.$props,
            multiple = _$props.multiple,
            disabled = _$props.disabled;

        var events = disabled ? {} : {
            click: this.onClick
        };
        var btnProps = {
            on: _extends({}, this.$listeners, events)
        };
        return h(
            "span",
            btnProps,
            [h("input", {
                attrs: {
                    type: "file",

                    multiple: multiple
                },
                key: this.uid,
                ref: "fileInputRef",
                style: { display: "none" }, on: {
                    "change": this.onChange
                }
            }), this.$slots["default"]]
        );
    }
};