import _extends from "babel-runtime/helpers/extends";
import AjaxUploader from "./ajax-uploader";
import UploadList from "./upload-list";
import SnToast from "../toast";

export default {
    name: "UpLoad",
    prefixCls: "sn-upload",
    props: {
        readOnly: {
            type: Boolean,
            "default": false
        },
        listType: {
            type: String,
            "default": "text"
        }, // or pictrue
        showPreviewIcon: {
            type: Boolean,
            "default": true
        },
        beforeUpload: Function,
        showUploadList: {
            type: Boolean,
            "default": true
        },
        action: {
            type: String,
            "default": ""
        },
        customRequest: Function,
        defaultFileList: {
            type: Array,
            "default": function _default() {
                return [];
            }
        },
        uploadOption: {
            type: Object,
            "default": function _default() {
                return {};
            }
        },
        method: {
            type: String,
            "default": "POST"
        }
    },
    data: function data() {
        return {
            // 上传的列表
            startFileList: [].concat(this.defaultFileList),
            // 上传成功的列表
            successFileList: [].concat(this.defaultFileList),
            // 上传失败的列表
            failFileList: []
        };
    },

    methods: {
        onClick: function onClick() {
            if (this.$refs.ajaxUpload) {
                this.$refs.ajaxUpload.onClick();
            }
        },
        start: function start(file) {
            if (file.status === "upload-error") {
                // 失败的重新上传 则修改对应索引的状态
                var index = this.getIndexByUid(this.startFileList, file);
                file.status = "uploading";
                this.startFileList.splice(index, 1, file);
            } else {
                file.status = "uploading";
                this.startFileList.push(file);
                this.$emit("onStart", file, this.startFileList);
            }
        },

        // 附件上传失败
        error: function error(info, result, file) {
            file.status = "upload-error";
            console.log("onError", info, result, file);
            var index = this.getIndexByUid(this.failFileList, file);
            // 失败列表不存在则添加进去
            if (index === -1) {
                this.failFileList.push(file);
            }
            SnToast(file.name + "\u4E0A\u4F20\u5931\u8D25");
            this.$emit("onError", file, this.failFileList);
        },
        progress: function progress(info, file) {
            if (!file.chunks) {
                file.percent = parseInt(info.loaded * 100 / file.size);
            }
            this.$emit("onProgress", info, file);
        },

        // 附件上传完成
        getUploadComplete: function getUploadComplete() {
            var completeFlag = false;
            // 没有上传列表
            if (this.startFileList.length === 0) {
                completeFlag = true;
                return completeFlag;
            }
            completeFlag = this.isAllLoaded();
            return completeFlag;
        },

        // 是否全部上传完成
        isAllLoaded: function isAllLoaded() {
            var completeFlag = (this.startFileList || []).every(function (item) {
                return item.status !== "uploading";
            });
            return completeFlag;
        },

        // 附件上传成功
        success: function success(file, result, xhr) {
            if (!file.chunks) {
                file.status = "uploaded";
            }
            // 附件上传最大值 数组索引为0
            if (this.uploadOption && this.uploadOption.maxUpNum && (this.startFileList || []).length > this.uploadOption.maxUpNum) {
                SnToast("\u6700\u591A\u53EA\u80FD\u6DFB\u52A0" + this.uploadOption.maxUpNum + "\u4E2A\u9644\u4EF6");
                return;
            }
            // 成功的文件是失败列表里面的 需要去除失败列表里面数据
            var index = this.getIndexByUid(this.failFileList, file);
            if (index !== -1) {
                this.failFileList.splice(index, 1);
            }
            this.successFileList.push(file);
            this.$emit("onSuccess", file, result);
        },

        // 获取数据里面对应value对象的索引
        getIndexByUid: function getIndexByUid(list, file) {
            return (list || []).findIndex(function (item) {
                return item.uid === file.uid;
            });
        },

        // 点击失败文件 重新上传
        handleError: function handleError(file, index) {
            this.$refs.ajaxUpload.post(file);
        },

        // 附件预览
        preview: function preview(file) {
            this.$emit("onPreview", file);
        },

        // 附件预览
        download: function download(file) {
            this.$emit("onDownload", file);
        },

        // 附件删除
        remove: function remove(file, index) {
            // 删除对应的当前上传完成的数据
            this.startFileList.splice(index, 1);
            this.removeSuccess(file);
            this.$emit("onRemove", file, index);
        },

        // 删除当前开始上传成功列表的数据
        removeSuccess: function removeSuccess(file) {
            var index = this.getIndexByUid(this.successFileList, file);
            if (index !== -1) {
                this.successFileList.splice(index, 1);
            }
        },

        // 附件上传之前
        reBeforeUpload: function reBeforeUpload(files) {
            if (!this.beforeUpload) {
                return true;
            }
            // 附件上传最大值 数组索引为0
            if (this.uploadOption && this.uploadOption.maxUpNum && (this.startFileList || []).length >= this.uploadOption.maxUpNum) {
                SnToast("\u6700\u591A\u53EA\u80FD\u6DFB\u52A0" + this.uploadOption.maxUpNum + "\u4E2A\u9644\u4EF6");
                return false;
            }
            var result = this.beforeUpload(files);
            if (result === false) {
                return false;
            } else if (result && result.then) {
                return result;
            }
            return true;
        },
        renderUploadList: function renderUploadList() {
            var h = this.$createElement;
            var _$props = this.$props,
                showUploadList = _$props.showUploadList,
                listType = _$props.listType;

            var uploadListProps = {
                props: {
                    items: this.startFileList,
                    listType: listType,
                    showRemoveIcon: !this.readOnly,
                    showPreviewIcon: this.showPreviewIcon
                },
                on: {
                    remove: this.remove,
                    preview: this.preview,
                    download: this.download,
                    handleError: this.handleError
                }
            };
            if (!showUploadList) {
                return null;
            } else {
                return h(UploadList, uploadListProps);
            }
        }
    },
    render: function render() {
        var h = arguments[0];

        var children = this.$slots["default"];
        // const { listType } = this.$props;
        var AjaxUploaderProps = {
            ref: "ajaxUpload",
            props: _extends({}, this.$props, {
                beforeUpload: this.reBeforeUpload
            }),
            on: {
                start: this.start,
                error: this.error,
                progress: this.progress,
                success: this.success
            }
        };

        var uploadList = this.renderUploadList();

        var uploadButton = this.readOnly ? null : h(
            AjaxUploader,
            AjaxUploaderProps,
            [" ", children]
        );

        var conMaps = ["upload", "list"];
        var list = function list() {
            return conMaps.map(function (type, index) {
                if (type === "list") {
                    return { uploadList: uploadList };
                } else {
                    return { uploadButton: uploadButton };
                }
            });
        };
        // if (listType === 'picture') {
        //     return (
        //         <transition-group>
        //             {uploadList}
        //             {uploadButton}
        //         </transition-group>
        //     );
        // }
        return h(
            "div",
            { "class": "sn-upload" },
            [uploadButton, this.$slots.middle ? this.$slots.middle : null, uploadList]
        );
    }
};