'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.getScroller = getScroller;
exports.getScrollTop = getScrollTop;
exports.setScrollTop = setScrollTop;
exports.getRootScrollTop = getRootScrollTop;
exports.setRootScrollTop = setRootScrollTop;
exports.getElementTop = getElementTop;
exports.getVisibleHeight = getVisibleHeight;
exports.getVisibleTop = getVisibleTop;
// get nearest scroll element
// http://w3help.org/zh-cn/causes/SD9013
// http://stackoverflow.com/questions/17016740/onscroll-function-is-not-working-for-chrome
var overflowScrollReg = /scroll|auto/i;
function getScroller(el) {
    var root = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : window;

    var node = el;

    while (node && node.tagName !== 'HTML' && node.nodeType === 1 && node !== root) {
        var _window$getComputedSt = window.getComputedStyle(node),
            overflowY = _window$getComputedSt.overflowY;

        if (overflowScrollReg.test(overflowY)) {
            if (node.tagName !== 'BODY') {
                return node;
            }

            var _window$getComputedSt2 = window.getComputedStyle(node.parentNode),
                htmlOverflowY = _window$getComputedSt2.overflowY;

            if (overflowScrollReg.test(htmlOverflowY)) {
                return node;
            }
        }
        node = node.parentNode;
    }

    return root;
}

function getScrollTop(element) {
    return 'scrollTop' in element ? element.scrollTop : element.pageYOffset;
}

function setScrollTop(element, value) {
    'scrollTop' in element ? element.scrollTop = value : element.scrollTo(element.scrollX, value);
}

function getRootScrollTop() {
    return window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0;
}

function setRootScrollTop(value) {
    setScrollTop(window, value);
    setScrollTop(document.body, value);
}

// get distance from element top to page top
function getElementTop(element) {
    return (element === window ? 0 : element.getBoundingClientRect().top) + getRootScrollTop();
}

function getVisibleHeight(element) {
    return element === window ? element.innerHeight : element.getBoundingClientRect().height;
}

function getVisibleTop(el) {
    if (isWindow(el)) {
        return 0;
    }
    return el.getBoundingClientRect().top;
}