'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _icon = require('../icon');

var _icon2 = _interopRequireDefault(_icon);

var _input = require('../mixins/input');

var _input2 = _interopRequireDefault(_input);

require('./index.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var NumberItem = {
    mixins: [_input2['default']],

    props: {
        // 是否有小数
        decimal: Boolean,
        // 数值精度
        precision: {
            type: Number,
            'default': 2
        },
        percent: Boolean,
        thousandSeparator: {
            type: Boolean,
            'default': true
        },
        unit: String
    },

    data: function data() {
        return {
            defaultValue: '',
            currentValue: '',
            displayValue: '',
            focus: false,
            lastKeyCode: null
        };
    },


    watch: {
        value: function value(val) {
            !this.focus && this.update(val);
        }
    },

    mounted: function mounted() {
        var value = this.value;


        if (value === undefined || value === null) {
            this.defaultValue = '';
        } else {
            this.defaultValue = '' + value;
        }

        this.update(this.defaultValue);
    },


    methods: {

        /**
         * 更新外部传入value值
         */
        update: function update(val) {
            if (val === undefined || val === null || val === '') {
                this.defaultValue = '';
                this.currentValue = this.defaultValue;
                !this.focus && this.formatter();
            } else if (!isNaN(parseInt(val))) {
                this.defaultValue = this.decimal ? parseFloat(val) : parseInt(val);
                this.currentValue = this.defaultValue;
                !this.focus && this.formatter();
            } else {
                this.defaultValue = '';
            }
        },


        /**
         * input输入
         */
        onInput: function onInput(e) {
            e = e || { target: this.$refs.inputRef };
            var el = e.target;
            var val = el.value;
            var pos = el.selectionStart;
            var decimal = this.decimal,
                precision = this.precision;

            console.log('input-number onInput === ');
            if (e.data === null && this.lastKeyCode !== 8 && this.lastKeyCode !== 46) {
                e.target.value = this.currentValue;
                return;
            }

            if (decimal) {
                var splitVal = val.split('.');

                // 如果小数点在首位则清空输入值
                if (val.indexOf('.') === 0) {
                    e.target.value = '';
                    return;
                }
                if (!this.isNumber(val) && val.indexOf('.') !== val.length - 1) {
                    e.target.value = this.currentValue;
                    return;
                }
                // 小数整数部分不能超过12位，小数部分不能超过2位
                if (splitVal[0].length > 12 || splitVal.length > 1 && splitVal[1].length > precision) {
                    e.target.value = this.currentValue;
                    return;
                }
            } else {
                if (val !== '' && !this.isInteger(val)) {
                    e.target.value = this.currentValue;
                    return;
                }
                // 整数不能超过12位
                if (val.length > 12) {
                    e.target.value = this.currentValue;
                    return;
                }
            }

            el.selectionStart = el.selectionEnd = pos;

            this.currentValue = val;
            this.$emit('input', val);
        },
        onFocus: function onFocus(e) {
            if (this.editable) {
                if (this.$refs.inputRef) {
                    this.$refs.inputRef.focus();
                    this.focus = true;
                }

                this.$emit('focus', e);
            }
        },
        onBlur: function onBlur(e) {
            var _this = this;

            setTimeout(function () {
                if (_this.$refs.inputRef) {
                    if (document.activeElement !== _this.$refs.inputRef) {
                        _this.formatter();
                        _this.focus = false;
                        _this.$emit('blur', e);
                    }
                }
            }, 150);
        },
        formatter: function formatter() {
            var decimal = this.decimal,
                precision = this.precision,
                percent = this.percent,
                unit = this.unit;

            var _displayValue = this.currentValue;

            if (percent) {
                Number(this.currentValue) > 100 && (this.currentValue = 100);
            }

            if (this.currentValue !== '') {
                _displayValue = this.transformThousandSeparator(this.currentValue, decimal ? precision : 0);

                if (percent) {
                    _displayValue = _displayValue + '%';
                }
            }

            this.displayValue = percent ? _displayValue : '' + _displayValue + (this.currentValue !== '' ? unit !== '' && unit !== undefined ? unit : '' : '');
        },


        /**
         * 千分位转换以及小数点保留位数
         */
        transformThousandSeparator: function transformThousandSeparator(val, precision) {
            if (typeof val !== "number") {
                val = Number(val);
            }
            var _val = void 0;
            /* 判断传入的小数点保留位数，没有则不截取 */
            if (arguments.length === 1) {
                _val = val.toString();
            } else {
                _val = val.toFixed(precision);
            }
            /* 判断传入的数值是否是整数，如果是，直接走原生千分位方法，不是，则通过正则处理为千分位 */
            if (_val.indexOf('.') === -1) {
                return val.toLocaleString();
            } else {
                return _val.replace(/(\d)(?=(\d{3})+\.)/g, '$1,');
            }
        },


        /**
         * 禁止输入非数字
         */
        onKeyDown: function onKeyDown(e) {
            var k = window.event ? e.keyCode : e.which;
            this.lastKeyCode = k;
            this.focus = true;

            /**
             * (k >= 48 && k <= 57) (k >= 96 && k <= 105) 主键盘和副键盘键入数字 0~9
             * k === 110 || k === 190 分别是主副小数点键
             * k === 46 删除键
             * k === 37 || k === 39 分别是左右键
             * k === 8 回退键
             * k === 0
             */
            var isInteger = k >= 48 && k <= 57 || k >= 96 && k <= 105 || k === 46 || k === 39 || k === 37 || k === 8 || k === 0;
            var isNumber = isInteger || k === 190 || k === 110;
            var rule = this.decimal ? isNumber : isInteger;

            if (rule) {
                return true;
            } else {
                if (window.event) {
                    window.event.returnValue = false;
                } else {
                    e.preventDefault();
                }

                return false;
            }
        },


        /**
         * change 事件
         */
        onChange: function onChange() {
            this.$emit('change', this.currentValue);
        },


        /**
         * 阻止在pc上焦点丢失
         */
        onClearMouseDown: function onClearMouseDown(e) {
            e.preventDefault();
        },


        /**
         * 清除输入框内容
         */
        onClear: function onClear() {
            this.displayValue = '';
            this.currentValue = '';
            this.$refs.inputRef.value = '';

            this.onFocus();
            this.$emit('input', '');
            this.$emit('clear');
        }
    },

    render: function render() {
        var h = arguments[0];
        var currentValue = this.currentValue,
            displayValue = this.displayValue,
            focus = this.focus,
            placeholder = this.placeholder,
            editable = this.editable,
            disabled = this.disabled,
            decimal = this.decimal,
            clear = this.clear;


        var _value = focus ? currentValue : displayValue;
        var inputType = decimal ? 'text' : 'tel';
        var renderClearIcon = focus && clear && editable && !disabled && currentValue && currentValue !== '' ? h(_icon2['default'], {
            attrs: {
                type: 'close-circle-fill'
            },
            'class': 'sn-input-number-clear',
            on: {
                'mousedown': this.onClearMouseDown,
                'click': this.onClear
            }
        }) : null;

        return h(
            'div',
            { 'class': 'sn-input-number' },
            [h('input', {
                ref: 'inputRef',
                attrs: { type: inputType,

                    placeholder: placeholder,
                    disabled: disabled,
                    readonly: !editable
                },
                'class': 'sn-input-number-control',
                domProps: {
                    'value': _value
                },
                on: {
                    'keydown': this.onKeyDown,
                    'input': this.onInput,
                    'focus': this.onFocus,
                    'blur': this.onBlur,
                    'change': this.onChange
                }
            }), renderClearIcon]
        );
    }
};
exports['default'] = NumberItem;
module.exports = exports.default;