'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _pickerView = require('../picker-view');

var _pickerView2 = _interopRequireDefault(_pickerView);

var _popup = require('../popup');

var _popup2 = _interopRequireDefault(_popup);

var _pickerView3 = require('../mixins/picker-view');

var _pickerView4 = _interopRequireDefault(_pickerView3);

var _transferDom = require('../directives/transfer-dom');

var _transferDom2 = _interopRequireDefault(_transferDom);

require('./index.less');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var Picker = {
    name: "Picker",
    mixins: [_pickerView4['default']],
    data: function data() {
        return {
            show: false,
            forceUpdate: false
        };
    },

    directives: { TransferDom: _transferDom2['default'] },
    props: {
        readonly: Boolean,
        value: [String, Number],
        title: String
    },
    created: function created() {
        this.currentValue = this.value;
    },
    mounted: function mounted() {},

    methods: {
        getDefaultIndex: function getDefaultIndex() {
            var columns = this.columns,
                value = this.value;

            if (columns.length && !columns[0].values) {
                return columns.indexOf(value);
            } else {
                return 0;
            }
        },
        onInput: function onInput(val) {
            this.show = val;
        },
        onShow: function onShow() {
            this.$emit('show');
        },
        onHide: function onHide() {
            var _this = this;

            this.show = false;
            this.$emit('hide');
            this.currentValue = this.value;
            setTimeout(function () {
                _this.forceUpdate = false;
            }, 150);
        },
        onClick: function onClick() {
            if (!this.readonly) {
                this.show = true;
                this.forceUpdate = true;
            }
        },
        onChange: function onChange(picker, value, index) {
            this.$emit('change', picker, value, index);
        },
        onCancel: function onCancel() {
            var _this2 = this;

            this.show = false;
            setTimeout(function () {
                _this2.forceUpdate = false;
            }, 150);

            this.$emit('cancel');
        },
        onConfirm: function onConfirm(picker, value) {
            var _this3 = this;

            if (!this.$listeners['confirm']) {
                this.$emit('input', value);
            }
            this.show = false;
            setTimeout(function () {
                _this3.forceUpdate = false;
            }, 150);

            this.$emit('confirm', picker, value);
        }
    },
    render: function render() {
        var h = arguments[0];
        var value = this.value,
            show = this.show,
            title = this.title,
            forceUpdate = this.forceUpdate,
            columns = this.columns;


        return h(
            'div',
            { 'class': 'sn-picker', on: {
                    'click': this.onClick
                }
            },
            [h(
                'span',
                { 'class': 'sn-picker-value' },
                [value]
            ), h(
                'div',
                {
                    directives: [{
                        name: 'transfer-dom',
                        value: true
                    }]
                },
                [h(
                    _popup2['default'],
                    {
                        attrs: { value: show },
                        on: {
                            'input': this.onInput,
                            'click-overlay': this.onHide
                        },
                        style: 'background: transparent;' },
                    [forceUpdate ? h(
                        'div',
                        { 'class': 'sn-picker-content' },
                        [h(_pickerView2['default'], {
                            attrs: {
                                'show-toolbar': true,
                                title: title,
                                defaultIndex: this.getDefaultIndex(),
                                columns: columns
                            },
                            on: {
                                'change': this.onChange,
                                'cancel': this.onCancel,
                                'confirm': this.onConfirm
                            }
                        })]
                    ) : null]
                )]
            )]
        );
    }
};

exports['default'] = Picker;
module.exports = exports.default;